# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/nlit',
                'doc_host': 'https://dsm-72.github.io',
                'git_url': 'https://github.com/dsm-72/nlit',
                'lib_path': 'nlit'},
  'syms': { 'nlit.args': {},
            'nlit.attr': {},
            'nlit.biol': {'nlit.biol.AnnPart': ('biol.html#annpart', 'nlit/biol.py')},
            'nlit.bkts': {},
            'nlit.byte': {},
            'nlit.cell': {},
            'nlit.clrs': {},
            'nlit.dict': {},
            'nlit.docs': {},
            'nlit.dund': {},
            'nlit.embs': {},
            'nlit.errs': {},
            'nlit.expo': { 'nlit.expo.Expo': ('expo.html#expo', 'nlit/expo.py'),
                           'nlit.expo.ExpoInfo': ('expo.html#expoinfo', 'nlit/expo.py')},
            'nlit.exps': {},
            'nlit.exts': {},
            'nlit.fmtx': {'nlit.fmtx.FilteredMatrixFile': ('fmtx.html#filteredmatrixfile', 'nlit/fmtx.py')},
            'nlit.hrdw': {},
            'nlit.math': {},
            'nlit.mods': {},
            'nlit.mthd': {},
            'nlit.narr': {},
            'nlit.nbks': {},
            'nlit.path': { 'nlit.path.EntryType': ('path.html#entrytype', 'nlit/path.py'),
                           'nlit.path.EntryType.kinds': ('path.html#entrytype.kinds', 'nlit/path.py'),
                           'nlit.path.OSType': ('path.html#ostype', 'nlit/path.py'),
                           'nlit.path.OSType.__str__': ('path.html#ostype.__str__', 'nlit/path.py'),
                           'nlit.path.OSType.addcls': ('path.html#ostype.addcls', 'nlit/path.py'),
                           'nlit.path.OSType.is_psx': ('path.html#ostype.is_psx', 'nlit/path.py'),
                           'nlit.path.OSType.is_wdx': ('path.html#ostype.is_wdx', 'nlit/path.py'),
                           'nlit.path.OSType.oscomp': ('path.html#ostype.oscomp', 'nlit/path.py'),
                           'nlit.path.OSType.osname': ('path.html#ostype.osname', 'nlit/path.py'),
                           'nlit.path.OSType.ostype': ('path.html#ostype.ostype', 'nlit/path.py'),
                           'nlit.path.OSType.pathlib_type': ('path.html#ostype.pathlib_type', 'nlit/path.py'),
                           'nlit.path.PathKind': ('path.html#pathkind', 'nlit/path.py'),
                           'nlit.path.PathKind.kinds': ('path.html#pathkind.kinds', 'nlit/path.py'),
                           'nlit.path.PathLibType': ('path.html#pathlibtype', 'nlit/path.py'),
                           'nlit.path.PathLibType.__str__': ('path.html#pathlibtype.__str__', 'nlit/path.py'),
                           'nlit.path.PathLibType.addcls': ('path.html#pathlibtype.addcls', 'nlit/path.py'),
                           'nlit.path.PathLibType.pthcls': ('path.html#pathlibtype.pthcls', 'nlit/path.py')},
            'nlit.pddf': {},
            'nlit.pkgs': {},
            'nlit.plot': {},
            'nlit.sund': {},
            'nlit.tens': {},
            'nlit.tree': {},
            'nlit.unit': {},
            'nlit.vals': {},
            'nlit.vers': {}}}
