# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/09_dict.ipynb.

# %% auto 0
__all__ = ['KEY', 'GET', 'VAL', 'DICT', 'PTTN_DICT']

# %% ../nbs/09_dict.ipynb 4
from .args import PTTN

# %% ../nbs/09_dict.ipynb 6
KEY = 'key'
GET = 'get'
VAL = 'val'

DICT = 'dict'


PTTN_DICT = f'{PTTN}_{DICT}'
