# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/90_unit.ipynb.

# %% auto 0
__all__ = ['ONE', 'TEN', 'HUNDRED', 'THOUSAND', 'MILLION', 'BILLION', 'TRILLION', 'QUADRILLION', 'QUINTILLION', 'SEXTILLION',
           'SEPTILLION', 'OCTILLION', 'NONILLION', 'TENTH', 'HUNDREDTH', 'THOUSANDTH', 'MILLIONTH', 'BILLIONTH',
           'TRILLIONTH', 'QUADRILLIONTH', 'QUINTILLIONTH', 'SEXTILLIONTH', 'SEPTILLIONTH', 'OCTILLIONTH', 'NONILLIONTH',
           'DECA', 'HECTO', 'KILO', 'MEGA', 'GIGA', 'TERA', 'PETA', 'EXA', 'ZETTA', 'YOTTA', 'RONNA', 'QUETTA', 'DECI',
           'CENTI', 'MILLI', 'MICRO', 'NANO', 'PICO', 'FEMTO', 'ATTO', 'ZEPTO', 'YOCTO', 'RONTO', 'QUECTO', 'da', 'h',
           'k', 'M', 'G', 'T', 'P', 'E', 'Z', 'Y', 'R', 'Q', 'd', 'c', 'm', 'u', 'n', 'p', 'f', 'a', 'z', 'y', 'r', 'q',
           'POS_NAMES', 'NEG_NAMES', 'UNIT_NAMES', 'POS_ABRVS', 'NEG_ABRVS', 'UNIT_ABRVS', 'POS_SYMBS', 'NEG_SYMBS',
           'UNIT_SYMBS']

# %% ../nbs/90_unit.ipynb 6
ONE = 'one'

TEN = 'ten'
HUNDRED = 'hundred'
THOUSAND = 'thousand'
MILLION = 'million'
BILLION = 'billion'
TRILLION = 'trillion'
QUADRILLION = 'quadrillion'
QUINTILLION = 'quintillion'
SEXTILLION = 'sextillion'
SEPTILLION = 'septillion'
OCTILLION = 'octillion'
NONILLION = 'nonillion'

TENTH = 'tenth'
HUNDREDTH = 'hundredth'
THOUSANDTH = 'thousandth'
MILLIONTH = 'millionth'
BILLIONTH = 'billionth'
TRILLIONTH = 'trillionth'
QUADRILLIONTH = 'quadrillionth'
QUINTILLIONTH = 'quintillionth'
SEXTILLIONTH = 'sextillionth'
SEPTILLIONTH = 'septillionth'
OCTILLIONTH = 'octillionth'
NONILLIONTH = 'nonillionth'

# %% ../nbs/90_unit.ipynb 8
DECA = 'deca'
HECTO = 'hecto'
KILO = 'kilo'
MEGA = 'mega'
GIGA = 'giga'
TERA = 'tera'
PETA = 'peta'
EXA = 'exa'
ZETTA = 'zetta'
YOTTA = 'yotta'
RONNA = 'ronna'
QUETTA = 'quetta'

DECI = 'deci'
CENTI = 'centi'
MILLI = 'milli'
MICRO = 'micro'
NANO = 'nano'
PICO = 'pico'
FEMTO = 'femto'
ATTO = 'atto'
ZEPTO = 'zepto'
YOCTO = 'yocto'
RONTO = 'ronto'
QUECTO = 'quecto'

# %% ../nbs/90_unit.ipynb 10
da = 'da'
h = 'h'
k = 'k'
M = 'M'
G = 'G'
T = 'T'
P = 'P'
E = 'E'
Z = 'Z'
Y = 'Y'
R = 'R'
Q = 'Q'
d = 'd'
c = 'c'
m = 'm'
u = 'u'
n = 'n'
p = 'p'
f = 'f'
a = 'a'
z = 'z'
y = 'y'
r = 'r'
q = 'q'

# %% ../nbs/90_unit.ipynb 13
POS_NAMES = (
    TEN, HUNDRED, THOUSAND, MILLION, BILLION, TRILLION, 
    QUADRILLION, QUINTILLION, SEXTILLION, SEPTILLION, OCTILLION, NONILLION
)

NEG_NAMES = (
    TENTH, HUNDREDTH, THOUSANDTH, MILLIONTH, BILLIONTH, TRILLIONTH, 
    QUADRILLIONTH, QUINTILLIONTH, SEXTILLIONTH, SEPTILLIONTH, OCTILLIONTH, NONILLIONTH
)

UNIT_NAMES = (ONE, ) + POS_NAMES + NEG_NAMES

# %% ../nbs/90_unit.ipynb 15
POS_ABRVS = (
    DECA, HECTO, KILO, MEGA, GIGA, TERA, PETA, EXA, ZETTA, YOTTA, RONNA, QUETTA
)
NEG_ABRVS = (
    DECI, CENTI, MILLI, MICRO, NANO, PICO, FEMTO, ATTO, ZEPTO, YOCTO, RONTO, QUECTO
)

UNIT_ABRVS = (None, ) + POS_ABRVS + NEG_ABRVS

# %% ../nbs/90_unit.ipynb 17
POS_SYMBS = (da, h, k, M, G, T, P, E, Z, Y, R, Q)
NEG_SYMBS = (d, c, m, u, n, p, f, a, z, y, r, q)

UNIT_SYMBS = (None, ) + POS_SYMBS +  NEG_SYMBS
