# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/62_pddf.ipynb.

# %% auto 0
__all__ = ['DF', 'DS', 'DATA', 'DATASET', 'DATAFRAME', 'IDX', 'INDEX', 'CAT', 'CATEGORY', 'CATEGORIES', 'COL', 'COLS', 'COLUMNS',
           'GET', 'SHAPE']

# %% ../nbs/62_pddf.ipynb 5
DF = 'df'
DS = 'ds'
DATA = 'data'
DATASET = f'{DATA}set'
DATAFRAME = f'{DATA}frame'

# %% ../nbs/62_pddf.ipynb 6
IDX = 'idx'
INDEX = 'index'

# %% ../nbs/62_pddf.ipynb 7
CAT = 'cat'
CATEGORY = f'{CAT}egory'
CATEGORIES = f'{CAT}egories'

# %% ../nbs/62_pddf.ipynb 8
COL = 'col'
COLS = f'{COL}s'
COLUMNS = f'{COL}umns'

# %% ../nbs/62_pddf.ipynb 9
GET = 'get'
SHAPE = f'shape'
